/*
 * @Author: qianhao
 * @Date: 2023-11-21 18:47:40
 * @LastEditors: qianhao
 * @LastEditTime: 2023-11-27 15:32:05
 * @Description: 
 * Copyright (c) 2019, YUNXI. All rights reserved.
 * YUNXI PROPRIETARY/CONFIDENTIAL. Use is subject to license terms. 
 */
import {
	defineComponent,
	PropType,
	h,
	ref,
	reactive,
	toRefs,
	onMounted,
	onUnmounted
} from 'vue'
import * as insertCss from 'insert-css';
// import myImage from '@/assets/A_evDjT5vjkX0AAAAAAAAAAAAAARQnAQ.png';
import myImage from '@assets/A_evDjT5vjkX0AAAAAAAAAAAAAARQnAQ.png';
// import screenfull from 'screenfull'
const image = {
	logo: "https://gw.alipayobjects.com/mdn/rms_43231b/afts/img/A*evDjT5vjkX0AAAAAAAAAAAAAARQnAQ",
	success:
		"https://gw.alipayobjects.com/mdn/rms_43231b/afts/img/A*6l60T6h8TTQAAAAAAAAAAAAAARQnAQ",
	failed:
		"https://gw.alipayobjects.com/mdn/rms_43231b/afts/img/A*SEISQ6My-HoAAAAAAAAAAAAAARQnAQ",
	running:
		"https://gw.alipayobjects.com/mdn/rms_43231b/afts/img/A*t8fURKfgSOgAAAAAAAAAAAAAARQnAQ",
};
interface NodeStatus {
	id: string
	status: 'default' | 'success' | 'failed' | 'running'
	label?: string
}
insertCss(`
.node {
  display: flex;
  align-items: center;
  width: 100%;
  height: 100%;
  background-color: #fff;
  border: 1px solid #c2c8d5;
  border-left: 4px solid #5F95FF;
  border-radius: 4px;
  box-shadow: 0 2px 5px 1px rgba(0, 0, 0, 0.06);
}
.node img {
  width: 20px;
  height: 20px;
  flex-shrink: 0;
  margin-left: 8px;
}
.node .label {
  display: inline-block;
  flex-shrink: 0;
  width: 104px;
  margin-left: 8px;
  color: #666;
  font-size: 12px;
}
.node .status {
  flex-shrink: 0;
}
.node.success {
  border-left: 4px solid #52c41a;
}
.node.failed {
  border-left: 4px solid #ff4d4f;
}
.node.running .status img {
  animation: spin 1s linear infinite;
}
.x6-node-selected .node {
  border-color: #1890ff;
  border-radius: 2px;
  box-shadow: 0 0 0 4px #d4e8fe;
}
.x6-node-selected .node.success {
  border-color: #52c41a;
  border-radius: 2px;
  box-shadow: 0 0 0 4px #ccecc0;
}
.x6-node-selected .node.failed {
  border-color: #ff4d4f;
  border-radius: 2px;
  box-shadow: 0 0 0 4px #fedcdc;
}
.x6-edge:hover path:nth-child(2){
  stroke: #1890ff;
  stroke-width: 1px;
}

.x6-edge-selected path:nth-child(2){
  stroke: #1890ff;
  stroke-width: 1.5px !important;
}

@keyframes running-line {
  to {
    stroke-dashoffset: -1000;
  }
}
@keyframes spin {
  from {
      transform: rotate(0deg);
  }
  to {
      transform: rotate(360deg);
  }
}
`);
const props = {
	getNode: {
		type: Function as PropType<any>,
	},
}
type MyFunction = () => any;
interface MyData {
	getData: MyFunction;
}
export default defineComponent({
	name: 'Test2',
	props,
	inject: ['getNode'],
	emits: ['confirmModal', 'refreshLogs', 'downloadLogs'],
	setup(props, ctx) {
		// const node = reactive({
		// 	isFullscreen: false
		// })
		let node = reactive<MyData>({
			getData: () => {},
		});
		onMounted(() => {
			node = props.getNode()
		})
		return {
			node
		}
	},
	render() {
		const node = this.node;
		console.log(node)
		let label2, status2 = 'default';
		if (node.getData) {
			console.log(node.getData)
			const data = node?.getData() as NodeStatus;
			console.log(data)
			const { label, status = 'default' } = data
			label2 = label
			status2 = status
		}
		

		return (
			<div class={`node ${status2}`}>
				<img src={image.logo} alt="logo" />
				<span class="label">{label2}</span>
				<span class="status">
					{status2 === 'success' && <img src={image.success} alt="success" />}
					{status2 === 'failed' && <img src={image.failed} alt="failed" />}
					{status2 === 'running' && <img src={image.running} alt="running" />}
				</span>
			</div>
		);
	}
})

